==> ocstore25_7_4.zip: OcStore/Spiky/ScriptCmd.h <==
#pragma once
#include "global.h"
//ǰ
class MyGame;
class GameMap;
class MapDrawer;
class GameScript;
class GameMsgbox;
class EntityRes;
class GameFade;
class MyCamera;
class GameUI;
class DmgNum;
class MapSystem;
class Entity;
class ItemSystem;
struct MyView;
//űӿ
class ScriptCmd
{
public:
	void Init(MyGame* game);
	//ҵĳͼ
	void TRA(const char* mapName_utf8, const char* eventName_utf8, int x, int y);
	void TRA(const char* mapName_utf8, const char* eventName_utf8, int x, int y, int hv, int offset);
	//luaű
	void DBG(const char* str_utf8);
	//ȴ
	void WAI(int wait);
	//ͣ¼ֱվڵ
	void WAS();
	//ıʽ
	void STY(const char* msgboxStyle_utf8);
	//ʾı
	void MSG(const char* msg_utf8, int mode);
	//Ϸı
	void MS2(const char* msg_utf8, int mode);
	//Ϸı
	void MS3(const char* msg_utf8, int mode);
	//Զı
	void MS4(const char* msg_utf8, int mode);
	//ıʾٶ
	void MSS(int speed);
	//ıʾٶ
	void TUR(bool tur);
	//z
	void NOD();
	//ı
	void CAT(const char* msg_utf8, int mode);
	//ı
	void CLR();
	//ղرı
	void CLO();
	//ıɫ
	void FCL(BYTE r, BYTE g, BYTE b, BYTE a);
	//
	void FNT(const char* fontFamily_utf8);
	//ֺ
	void FSZ();
	void FSZ(int fontSize);
	//ͷ
	void FAC(const char* faceID);
	//رͷ
	void FAC();
	//org
	void CMU(const char* musicName_utf8, float fadeInSecond);
	//ͣorg
	void PMU(float fadeOutSecond);
	//ָorg
	void RMU(float fadeInSecond);
	//wav
	void SOU(const char* soundName_utf8);
	//ogg
	void CMU2(const char* musicName_utf8, float fadeInSecond);
	//ͣogg
	void PMU2(float fadeOutSecond);
	//ָogg
	void RMU2(float fadeInSecond);
	//¼ǰסϷ
	void PRI();
	//¼ǰס
	void KEY(bool bKey = true);
	//ҵˮƽٶΪ0
	void MM0();
	void MM0(int playerIndex);
	//ٶ0
	void MV0();
	void MV0(int playerIndex);
	//Ƶ
	void MOV(int x, int y);
	void MOV(int x, int y, int hv, int offset);
	void MOV(int x, int y, int playerIndex);
	void MOV(int x, int y, int hv, int offset, int playerIndex);
	void MOV(int x, int y, const char* globalEntityID_utf8);
	void MOV(int x, int y, int hv, int offset, const char* globalEntityID_utf8);
	void MOV(const char* eventName_utf8);
	void MOV(const char* eventName_utf8, int playerIndex);
	void MOV(int playerIndex);
	//ҵ泯
	void SLR(int lr);
	void SLR(int lr, int playerIndex);
	void SLR(const char* eventName_utf8, int playerIndex);
	void SLR(const char* eventName_utf8);
	//ȡҵ泯
	int GLR(int playerIndex);
	//Һ
	void MYB(int lr);
	void MYB(int lr, int playerIndex);
	//۽Npc
	void FON(const char* eventName_utf8, float focusTimes);
	//۽
	void FOM(float focusTimes);
	void FOM(float focusTimes, int playerIndex);
	//ʾͼ
	void MNA();
	//
	void FAI(int direction);
	//
	void FAO(int direction);
	//
	void HMC();
	void HMC(int playerIndex);
	void HMC(const char* globalEntityID_utf8);
	//ʾ
	void SMC();
	void SMC(int playerIndex);
	void SMC(const char* globalEntityID_utf8);
	//Npc
	void ANP(int stateID);
	void ANP(const char* eventName_utf8, int stateID, int lr);
	void ANP(const char* eventName_utf8, int stateID);
	void ANP(const char* stateName_utf8);
	void ANP(const char* eventName_utf8, const char* stateName_utf8, int lr);
	void ANP(const char* eventName_utf8, const char* stateName_utf8);
	//Ҷ
	void AMC(int stateID);
	void AMC(int stateID, int lr);
	void AMC(int stateID, int lr, int playerIndex);
	void AMC(int stateID, int lr, const char* globalEntityID_utf8);
	void AMC(int stateID, const char* mycharName_utf8);
	void AMC(const char* stateName_utf8);
	void AMC(const char* stateName_utf8, int lr);
	void AMC(const char* stateName_utf8, int lr, int playerIndex);
	void AMC(const char* stateName_utf8, int lr, const char* globalEntityID_utf8);
	void AMC(const char* stateName_utf8, const char* mycharName_utf8);
	//ĳһNpc
	void ATP(const char* npcName_utf8, const char* stateName_utf8);
	//Ҷ
	void TMC(bool enable);
	void TMC(bool enable, int playerIndex);
	//Npc
	void TNP(const char* eventName_utf8, bool enable);
	//滻NPC
	void CNP(const char* eventName_utf8, const char* npcName_utf8, int stateID, int lr);
	void CNP(const char* eventName_utf8, const char* npcName_utf8, int stateID);
	void CNP(const char* eventNameSrc_utf8, const char* eventNameDst_utf8);
	//ƶNpc
	void MNP(const char* eventName_utf8, int x, int y, int lr);
	void MNP(const char* eventName_utf8, const char* dstEventName_utf8);
	//Bossս(ʾbossѪ)
	void BSL(const char* eventName_utf8, int lineSize);
	void BSL(const char* eventName_utf8);
	//Ϸ
	void SAV();
	//ͼɼ
	void LAY(const char* layerName_utf8, bool bVisible);
	//flag
	void FLP(const char* flagName_utf8);
	//Ƴflag
	void FLS(const char* flagName_utf8);
	//flagǷ
	bool FLJ(const char* flagName_utf8);
	//YesNoѡ
	void YNJ();
	//һYNJѡ
	bool YES();
	//Ϸ
	void INI();
	//ر⻭
	void ESC();
	//¼ʱıʾ
	void W99();
	//ʾϷͼ
	void MAP();
	//ȡһε¼±
	int PLY();
	//NPC
	void SNP(const char* npcName_utf8,int x,int y,int lr, const char* layerName_utf8, const char* eventName_utf8);
	//ɾNPC
	void DNP(const char* eventName_utf8);
	void DNP();//ɾڵĶ
	//ֵ
	void MLP(int val);
	void MLP(int val, int playerIndex);
	//ⷿǷĳ¼ʵ
	bool ECJ(const char* eventName_utf8);
	//ָ
	void LIP(int val);
	void LIP(int val, int playerIndex);
	//ȡ¼Ĵ
	const char* TGR();
	//ʵԤ
	void ELT(const char* npcName_utf8, const char* eventName_utf8, const char* triggerType_utf8);
	void ELT(const char* npcName_utf8);
	void ELT();
	//ҿƵȫʵ
	void SPL(int playerIndex, const char* globalEntityID_utf8);
	//ȫNPC
	void SGP(const char* npcName_utf8, int x, int y, int lr, const char* globalEntityID_utf8);
	//Ʋһȫֵλ
	void CGP(const char* srcGlobalEntityID_utf8, const char* dstGlobalEntityID_utf8);
	//ɾȫNPC
	void DGP(const char* globalEntityID_utf8);
	//AIȫNPC
	void AGP(const char* globalEntityID_utf8, bool enableAI, const char* followID_utf8 = nullptr);
	//2AIлúͽֹ
	void P2A(bool bEnable);
	//ĿǷˮ
	bool WET();
	//صĿʵid
	const char* EID();
	//עƷ
	void RGI(const char* regID_utf8, const char* iconEntityName_utf8,
		const char* functionName_utf8, const char* checkFunctionName_utf8, bool stackable);
	//ƷظƷ
	int ITP(const char* regID_utf8, int num);
	int ITP(const wchar_t* regID, int num);
	//ƳƷ-1ΪƳȫ,ʣ
	int ITS(const char* regID_utf8, int num);
	int ITS(const wchar_t* regID, int num);
	int ITS();//ƳƷ
	//ǷӵĳƷ
	bool ITJ(const char* regID_utf8, int num);
	//ӵĳƷ
	int ITC(const char* regID_utf8);
	int ITC(const wchar_t* regID);
	//ע
	void RGM(const char* regID_utf8, const char* iconEntityName_utf8,
		const char* missionName_utf8, const char* functionName_utf8, const char* checkFunctionName_utf8);
	//
	void MSA(const char* regID_utf8);
	//ɾ
	void MSD(const char* regID_utf8);
	void MSD();
	//滻
	void MSR(const char* regID_src_utf8, const char* regID_dst_utf8);
	//Ƿӵĳ
	bool MSJ(const char* regID_utf8);
	//лϷcmd
	void SUB(bool bSub);
	//Ʒ޷
	void LOC(int checkItemIndex, bool bLock);
	//ǰƷǷ
	bool LOC(int checkItemIndex);
	//չʾĳƷ
	void GIT(const char* regID_utf8, int num);
	void GIT();
	//ǰǷʹϷ
	bool IsMainGame();
	//ȡǰڵƷ±
	int GetCheckItemIndex();
	//ݵUI
	void IMM();
	//ÿ
	void SKP(const char* flagName_utf8);
	//Ƴ
	void SKS(const char* flagName_utf8);
	//Ƿ
	bool SKJ(const char* flagName_utf8);
	//
	void POS(bool save = false);
	//µͼϵƬ
	void CMP(const char* layerCopyFrom_utf8, const char* layerCopyTo_utf8);
	void CMP(const char* layerCopyFrom_utf8, const char* layerCopyTo_utf8, const char* smokeNpcName_utf8);
	//ζĻ
	void QUA(int times, int mode);
	//滻µҽɫ
	void SWC(int playerIndex, const char* npcName_utf8, const char* globalEntityID_utf8, bool extendHpMax);
	//12Ľɫ
	void SWP();
	//ȡҵĽɫ
	const char* MCN(int playerIndex);
	//ȡ±
	int MCI(const char* mycharName_utf8);
	//ȡǰϷģʽ
	int GOP();
	//
	void FLA(int times = 20);
	//ɱĳһ͵ĵˣػɱ
	int KIL(const char* npcName_utf8,int damage = 9999);
	//שƻЧ
	void STA(const char* smokeNpcName_utf8, int num, const char* soundName_utf8);
	//MP
	void ZAM();
	void ZAM(int playerIndex);
	//λùؿе
	void RST(std::vector<std::wstring>& nameArr);
	//ʼβ´
	void CRE(const char* creditName_utf8);
	void CRE();//رսβ´
	//ȡҰı
	const char* KEN(int playerIndex, int keyIndex);
	//ȡǰϷѶ
	int DIF();
private:
	MyGame* game = nullptr;
	MyView* pView = nullptr;
	GameMap* pGameMap = nullptr;
	MapDrawer* pMapDrawer = nullptr;
	GameScript* pGameScrpt = nullptr;
	GameMsgbox* pGameMsgbox = nullptr;
	EntityRes* pEntityRes = nullptr;
	GameFade* pGameFade = nullptr;
	MyCamera* pCamera = nullptr;
	GameUI* pGameUI = nullptr;
	std::set<std::wstring>* pFlagSet = nullptr;
	std::set<std::wstring>* pSkipSet = nullptr;
	DmgNum* dmgNum = nullptr;
	MapSystem* pMapSystem = nullptr;
	ItemSystem* pItemSystem = nullptr;
	int* pCheckEventPlayerIndex = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player1 = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player2 = nullptr;
	std::unordered_map<std::wstring, std::weak_ptr<Entity>>* globalEntityTable = nullptr;
	std::list<std::shared_ptr<Entity>>* globalEntity = nullptr;
	std::list<std::shared_ptr<Entity>>* globalEntity_addList = nullptr;
	std::vector<wchar_t> wbuff, wbuff2, wbuff3, wbuff4, wbuff5;
	std::vector<char> utf8;
	int lastWordCount = 0;
	//ʹϷָ
	bool usingMainGameCmd = false;
};

==> ocstore25_8_11.zip: OcStore/Spiky/ScriptCmd.h <==
#pragma once
#include "global.h"
//ǰ
class MyGame;
class GameMap;
class MapDrawer;
class GameScript;
class GameMsgbox;
class EntityRes;
class GameFade;
class MyCamera;
class GameUI;
class DmgNum;
class MapSystem;
class Entity;
class ItemSystem;
struct MyView;
//űӿ
class ScriptCmd
{
public:
	void Init(MyGame* game);
	//ҵĳͼ
	void TRA(const char* mapName_utf8, const char* eventName_utf8, int x, int y);
	void TRA(const char* mapName_utf8, const char* eventName_utf8, int x, int y, int hv, int offset);
	//luaű
	void DBG(const char* str_utf8);
	//ȴ
	void WAI(int wait);
	//ͣ¼ֱվڵ
	void WAS();
	//ıʽ
	void STY(const char* msgboxStyle_utf8);
	//ʾı
	void MSG(const char* msg_utf8, int mode);
	//Ϸı
	void MS2(const char* msg_utf8, int mode);
	//Ϸı
	void MS3(const char* msg_utf8, int mode);
	//Զı
	void MS4(const char* msg_utf8, int mode);
	//ıʾٶ
	void MSS(int speed);
	//ıʾٶ
	void TUR(bool tur);
	//z
	void NOD();
	//ı
	void CAT(const char* msg_utf8, int mode);
	//ı
	void CLR();
	//ղرı
	void CLO();
	//ıɫ
	void FCL(BYTE r, BYTE g, BYTE b, BYTE a);
	//
	void FNT(const char* fontFamily_utf8);
	//ֺ
	void FSZ();
	void FSZ(int fontSize);
	//ͷ
	void FAC(const char* faceID);
	//رͷ
	void FAC();
	//org
	void CMU(const char* musicName_utf8, float fadeInSecond);
	//ͣorg
	void PMU(float fadeOutSecond);
	//ָorg
	void RMU(float fadeInSecond);
	//wav
	void SOU(const char* soundName_utf8);
	//ogg
	void CMU2(const char* musicName_utf8, float fadeInSecond);
	//ͣogg
	void PMU2(float fadeOutSecond);
	//ָogg
	void RMU2(float fadeInSecond);
	//¼ǰסϷ
	void PRI();
	//¼ǰס
	void KEY(bool bKey = true);
	//ҵˮƽٶΪ0
	void MM0();
	void MM0(int playerIndex);
	//ٶ0
	void MV0();
	void MV0(int playerIndex);
	//Ƶ
	void MOV(int x, int y);
	void MOV(int x, int y, int hv, int offset);
	void MOV(int x, int y, int playerIndex);
	void MOV(int x, int y, int hv, int offset, int playerIndex);
	void MOV(int x, int y, const char* globalEntityID_utf8);
	void MOV(int x, int y, int hv, int offset, const char* globalEntityID_utf8);
	void MOV(const char* eventName_utf8);
	void MOV(const char* eventName_utf8, int playerIndex);
	void MOV(int playerIndex);
	//ҵ泯
	void SLR(int lr);
	void SLR(int lr, int playerIndex);
	void SLR(const char* eventName_utf8, int playerIndex);
	void SLR(const char* eventName_utf8);
	//ȡҵ泯
	int GLR(int playerIndex);
	//Һ
	void MYB(int lr);
	void MYB(int lr, int playerIndex);
	//۽Npc
	void FON(const char* eventName_utf8, float focusTimes);
	//۽
	void FOM(float focusTimes);
	void FOM(float focusTimes, int playerIndex);
	//ʾͼ
	void MNA();
	//
	void FAI(int direction);
	//
	void FAO(int direction);
	//
	void HMC();
	void HMC(int playerIndex);
	void HMC(const char* globalEntityID_utf8);
	//ʾ
	void SMC();
	void SMC(int playerIndex);
	void SMC(const char* globalEntityID_utf8);
	//Npc
	void ANP(int stateID);
	void ANP(const char* eventName_utf8, int stateID, int lr);
	void ANP(const char* eventName_utf8, int stateID);
	void ANP(const char* stateName_utf8);
	void ANP(const char* eventName_utf8, const char* stateName_utf8, int lr);
	void ANP(const char* eventName_utf8, const char* stateName_utf8);
	//Ҷ
	void AMC(int stateID);
	void AMC(int stateID, int lr);
	void AMC(int stateID, int lr, int playerIndex);
	void AMC(int stateID, int lr, const char* globalEntityID_utf8);
	void AMC(int stateID, const char* mycharName_utf8);
	void AMC(const char* stateName_utf8);
	void AMC(const char* stateName_utf8, int lr);
	void AMC(const char* stateName_utf8, int lr, int playerIndex);
	void AMC(const char* stateName_utf8, int lr, const char* globalEntityID_utf8);
	void AMC(const char* stateName_utf8, const char* mycharName_utf8);
	//ĳһNpc
	void ATP(const char* npcName_utf8, const char* stateName_utf8);
	//Ҷ
	void TMC(bool enable);
	void TMC(bool enable, int playerIndex);
	//Npc
	void TNP(const char* eventName_utf8, bool enable);
	//滻NPC
	void CNP(const char* eventName_utf8, const char* npcName_utf8, int stateID, int lr);
	void CNP(const char* eventName_utf8, const char* npcName_utf8, int stateID);
	void CNP(const char* eventNameSrc_utf8, const char* eventNameDst_utf8);
	//ƶNpc
	void MNP(const char* eventName_utf8, int x, int y, int lr);
	void MNP(const char* eventName_utf8, const char* dstEventName_utf8);
	//Bossս(ʾbossѪ)
	void BSL(const char* eventName_utf8, int lineSize);
	void BSL(const char* eventName_utf8);
	//Ϸ
	void SAV();
	//ͼɼ
	void LAY(const char* layerName_utf8, bool bVisible);
	//flag
	void FLP(const char* flagName_utf8);
	//Ƴflag
	void FLS(const char* flagName_utf8);
	//flagǷ
	bool FLJ(const char* flagName_utf8);
	//YesNoѡ
	void YNJ();
	//һYNJѡ
	bool YES();
	//Ϸ
	void INI();
	//ر⻭
	void ESC();
	//¼ʱıʾ
	void W99();
	//ʾϷͼ
	void MAP();
	//ȡһε¼±
	int PLY();
	//NPC
	void SNP(const char* npcName_utf8,int x,int y,int lr, const char* layerName_utf8, const char* eventName_utf8);
	//ɾNPC
	void DNP(const char* eventName_utf8);
	void DNP();//ɾڵĶ
	//ֵ
	void MLP(int val);
	void MLP(int val, int playerIndex);
	//ⷿǷĳ¼ʵ
	bool ECJ(const char* eventName_utf8);
	//ָ
	void LIP(int val);
	void LIP(int val, int playerIndex);
	//ָ
	void MIP(int val);
	void MIP(int val, int playerIndex);
	//ȡ¼Ĵ
	const char* TGR();
	//ʵԤ
	void ELT(const char* npcName_utf8, const char* eventName_utf8, const char* triggerType_utf8);
	void ELT(const char* npcName_utf8);
	void ELT();
	//ҿƵȫʵ
	void SPL(int playerIndex, const char* globalEntityID_utf8);
	//ȫNPC
	void SGP(const char* npcName_utf8, int x, int y, int lr, const char* globalEntityID_utf8);
	//Ʋһȫֵλ
	void CGP(const char* srcGlobalEntityID_utf8, const char* dstGlobalEntityID_utf8);
	//ɾȫNPC
	void DGP(const char* globalEntityID_utf8);
	//AIȫNPC
	void AGP(const char* globalEntityID_utf8, bool enableAI, const char* followID_utf8 = nullptr);
	//2AIлúͽֹ
	void P2A(bool bEnable);
	//ĿǷˮ
	bool WET();
	//صĿʵid
	const char* EID();
	//עƷ
	void RGI(const char* regID_utf8, const char* iconEntityName_utf8,
		const char* functionName_utf8, const char* checkFunctionName_utf8, bool stackable);
	//ƷظƷ
	int ITP(const char* regID_utf8, int num);
	int ITP(const wchar_t* regID, int num);
	//ƳƷ-1ΪƳȫ,ʣ
	int ITS(const char* regID_utf8, int num);
	int ITS(const wchar_t* regID, int num);
	int ITS();//ƳƷ
	//ǷӵĳƷ
	bool ITJ(const char* regID_utf8, int num);
	//ӵĳƷ
	int ITC(const char* regID_utf8);
	int ITC(const wchar_t* regID);
	//ע
	void RGM(const char* regID_utf8, const char* iconEntityName_utf8,
		const char* missionName_utf8, const char* functionName_utf8, const char* checkFunctionName_utf8);
	//
	void MSA(const char* regID_utf8);
	//ɾ
	void MSD(const char* regID_utf8);
	void MSD();
	//滻
	void MSR(const char* regID_src_utf8, const char* regID_dst_utf8);
	//Ƿӵĳ
	bool MSJ(const char* regID_utf8);
	//лϷcmd
	void SUB(bool bSub);
	//Ʒ޷
	void LOC(int checkItemIndex, bool bLock);
	//ǰƷǷ
	bool LOC(int checkItemIndex);
	//չʾĳƷ
	void GIT(const char* regID_utf8, int num);
	void GIT();
	//ǰǷʹϷ
	bool IsMainGame();
	//ȡǰڵƷ±
	int GetCheckItemIndex();
	//ݵUI
	void IMM();
	//ÿ
	void SKP(const char* flagName_utf8);
	//Ƴ
	void SKS(const char* flagName_utf8);
	//Ƿ
	bool SKJ(const char* flagName_utf8);
	//
	void POS(bool save = false);
	//µͼϵƬ
	void CMP(const char* layerCopyFrom_utf8, const char* layerCopyTo_utf8);
	void CMP(const char* layerCopyFrom_utf8, const char* layerCopyTo_utf8, const char* smokeNpcName_utf8);
	//ζĻ
	void QUA(int times, int mode);
	//滻µҽɫ
	void SWC(int playerIndex, const char* npcName_utf8, const char* globalEntityID_utf8, bool extendHpMax);
	//12Ľɫ
	void SWP();
	//ȡҵĽɫ
	const char* MCN(int playerIndex);
	//ȡ±
	int MCI(const char* mycharName_utf8);
	//ȡǰϷģʽ
	int GOP();
	//
	void FLA(int times = 20);
	//ɱĳһ͵ĵˣػɱ
	int KIL(const char* npcName_utf8,int damage = 9999);
	//שƻЧ
	void STA(const char* smokeNpcName_utf8, int num, const char* soundName_utf8);
	//MP
	void ZAM();
	void ZAM(int playerIndex);
	//λùؿе
	void RST(std::vector<std::wstring>& nameArr);
	//ʼβ´
	void CRE(const char* creditName_utf8);
	void CRE();//رսβ´
	//ȡҰı
	const char* KEN(int playerIndex, int keyIndex);
	//ȡǰϷѶ
	int DIF();
	//ʾʼʱ
	void TIM(bool visiable, bool start);
	//ʱ
	bool STC();
	//ȡʱ
	bool LTC();
private:
	MyGame* game = nullptr;
	MyView* pView = nullptr;
	GameMap* pGameMap = nullptr;
	MapDrawer* pMapDrawer = nullptr;
	GameScript* pGameScrpt = nullptr;
	GameMsgbox* pGameMsgbox = nullptr;
	EntityRes* pEntityRes = nullptr;
	GameFade* pGameFade = nullptr;
	MyCamera* pCamera = nullptr;
	GameUI* pGameUI = nullptr;
	std::set<std::wstring>* pFlagSet = nullptr;
	std::set<std::wstring>* pSkipSet = nullptr;
	DmgNum* dmgNum = nullptr;
	MapSystem* pMapSystem = nullptr;
	ItemSystem* pItemSystem = nullptr;
	int* pCheckEventPlayerIndex = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player1 = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player2 = nullptr;
	std::unordered_map<std::wstring, std::weak_ptr<Entity>>* globalEntityTable = nullptr;
	std::list<std::shared_ptr<Entity>>* globalEntity = nullptr;
	std::list<std::shared_ptr<Entity>>* globalEntity_addList = nullptr;
	std::vector<wchar_t> wbuff, wbuff2, wbuff3, wbuff4, wbuff5;
	std::vector<char> utf8;
	int lastWordCount = 0;
	//ʹϷָ
	bool usingMainGameCmd = false;
};
